# Changelog

All notable changes to this project will be documented in this file.

## [0.3.0] - 2025-01-09

### 🚀 Features

- Autolink to classes inside project and show inherited classes

### 📚 Documentation

- Use version from git tag

### ⚙️ Miscellaneous Tasks

- Fix download for package signing step

## [0.2.1] - 2025-01-08

### 🚀 Features

- Generate asciidoc from pydoc strings

### 🐛 Bug Fixes

- Ignore builtin routines, e.g. __str__
- Restrict python version to >3.11
- Assume routines are not user defined if they lack __module__

### 📚 Documentation

- Add basic readme

### ⚙️ Miscellaneous Tasks

- Setup repo
- Setup doc building with antora
- Build with uv instead of python -m build
- Add project description and remove download field from docs

<!-- generated by git-cliff -->
